ALLOWPOST = intern('allowpost')
ALLOWRAW = intern('allowraw')
ALTPART = intern('alt_part')
AUTHORID = intern('authorid')
AUTHOR = intern('author')
BASE = intern('base')
BODY = intern('body')
CLASS = intern('class')
COMMAND = intern('cmd')
COOKIES = intern('cookies')
CSSPREFIX = intern('cssprefix')
DATE = intern('date')
DATESORT = intern('date_sort')
ERROR = intern('error')
EZMLM = intern('ezmlm')
FEEDMSGS = intern('feedmsgs')
FEEDTYPE = intern('feedtype')
FILENAME = intern('filename')
FIRSTMONTH = intern('first_month')
FORMATTIME = intern('format_time')
HEADERS = intern('headers')
ITEM = intern('item')
LASTMONTH = intern('last_month')
LISTDESC = intern('listdesc')
LISTDIR = intern('listdir')
LISTEMAIL = intern('listemail')
LIST = intern('list')
LISTSUB = intern('listsub')
WRAPWIDTH = intern('wrapwidth')
MENUBAR = intern('menubar')
MESSAGE = intern('message')
MESSAGES = intern('messages')
MONTH = intern('month')
MONTHNAME = intern('month_name')
MSGCOUNT = intern('msgcount')
MSGNUM = intern('msgnum')
MSGSPERPAGE = intern('msgsperpage')
NAME = intern('name')
NEXTMONTH = intern('next_month')
PAGE = intern('page')
PAGES = intern('pages')
PART = intern('part')
PERPAGE = intern('perpage')
PREVMONTH = intern('prev_month')
ROW = intern('row')
STYLE = intern('style')
SUBJECT = intern('subject')
TERMS = intern('terms')
THREADID = intern('threadid')
THREADS = intern('threads')
TIMESTAMP = intern('timestamp')
TIMESTR = intern('timestr')
TITLE = intern('title')
TYPE = intern('type')
TZ = intern('tz')
VALUE = intern('value')
YEAR = intern('year')
